import {
  Metadata,
  Http,
} from '@zeedhi/core';
import {
  Modal,
  ModalService,
  Form,
  Select,
  GridEditable,
} from '@zeedhi/common';

export class FilterParamDashModalController {
  private filterParamDashModal!: Modal;
  
  public async createFilterParamDashModal() {
    await this.checkedPanel();
    this.filterParamDashModal = await ModalService.createFromJson('/modals/filterParamDashModal', true);
    this.openFilterParamDashModal();
  }
  
  public openFilterParamDashModal() {
    this.filterParamDashModal.show();
  }
  
  public closeFilterParamDashModal() {
    this.filterParamDashModal.hide();
    this.clearInputsFilter();
  }
  
  public clearInputsFilter() {
    const form = Metadata.getInstance<Form>('formFilterParamDash');
    form.clearForm();
  }
  
  public applyFilterDash() {
    const filter = Metadata.getInstance<Form>('formFilterParamDash');
    const grid = Metadata.getInstance<GridEditable>('parametersEditGrid');
    
    if (filter.value.CDFILIAL != null && filter.value.NRPAINEL != null) {
      const conditions = {
        CDFILIAL: filter.value.CDFILIAL.CDFILIAL,
        NRPAINEL: filter.value.NRPAINEL.NRPAINEL,
      };
      this.filterParamDashModal.hide();
      grid.datasource.filter = conditions;
      grid.datasource.get();
    } else {
      filter.validate();
    }
  }
  
  public checkedPanel() {
    Http.post('/reviewFiltePanel');
  }
  
  public validateDataSourceLimit() {
    const filter = Metadata.getInstance<Form>('formFilterParamDash');
    const data = filter.getChildInstance<Select>('CDFILIAL').datasource;
    data.setLimit(5);
  }
}
